@@ -250,30 +250,30 @@ static inline void DebugReportFlagsToAnnotFlags(VkDebugReportFlagsEXT dr_flags,
     *da_type = 0;
     // If it's explicitly listed as a performance warning, treat it as a performance message. Otherwise, treat it as a validation
     // issue.
-    if ((dr_flags & VK_DEBUG_REPORT_PERFORMANCE_WARNING_BIT_EXT) != 0) {
+    if ((dr_flags & kPerformanceWarningBit) != 0) {
         *da_type |= VK_DEBUG_UTILS_MESSAGE_TYPE_PERFORMANCE_BIT_EXT;
         *da_severity |= VK_DEBUG_UTILS_MESSAGE_SEVERITY_WARNING_BIT_EXT;
     }
-    if ((dr_flags & VK_DEBUG_REPORT_DEBUG_BIT_EXT) != 0) {
+    if ((dr_flags & kDebugBit) != 0) {
         *da_type |= VK_DEBUG_UTILS_MESSAGE_TYPE_GENERAL_BIT_EXT | VK_DEBUG_UTILS_MESSAGE_TYPE_VALIDATION_BIT_EXT;
         *da_severity |= VK_DEBUG_UTILS_MESSAGE_SEVERITY_VERBOSE_BIT_EXT;
     }
-    if ((dr_flags & VK_DEBUG_REPORT_INFORMATION_BIT_EXT) != 0) {
+    if ((dr_flags & kInformationBit) != 0) {
         *da_type |= VK_DEBUG_UTILS_MESSAGE_TYPE_VALIDATION_BIT_EXT;
         *da_severity |= VK_DEBUG_UTILS_MESSAGE_SEVERITY_INFO_BIT_EXT;
     }
-    if ((dr_flags & VK_DEBUG_REPORT_WARNING_BIT_EXT) != 0) {
+    if ((dr_flags & kWarningBit) != 0) {
         *da_type |= VK_DEBUG_UTILS_MESSAGE_TYPE_VALIDATION_BIT_EXT;
         *da_severity |= VK_DEBUG_UTILS_MESSAGE_SEVERITY_WARNING_BIT_EXT;
     }
-    if ((dr_flags & VK_DEBUG_REPORT_ERROR_BIT_EXT) != 0) {
+    if ((dr_flags & kErrorBit) != 0) {
         *da_type |= VK_DEBUG_UTILS_MESSAGE_TYPE_VALIDATION_BIT_EXT;
         *da_severity |= VK_DEBUG_UTILS_MESSAGE_SEVERITY_ERROR_BIT_EXT;
     }
 }
 
 // Forward Declarations
-static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags msg_flags, VkDebugReportObjectTypeEXT object_type,
+static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags msg_flags, VkObjectType object_type,
                                  uint64_t src_object, size_t location, const char *layer_prefix, const char *message,
                                  const char *text_vuid);
 
@@ -314,7 +314,7 @@ static inline void RemoveAllMessageCallbacks(debug_report_data *debug_data, std:
     callbacks.clear();
 }
 
-static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags msg_flags, VkDebugReportObjectTypeEXT object_type,
+static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags msg_flags, VkObjectType object_type,
                                  uint64_t src_object, size_t location, const char *layer_prefix, const char *message,
                                  const char *text_vuid) {
     bool bail = false;
@@ -328,7 +328,7 @@ static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags ms
     DebugReportFlagsToAnnotFlags(msg_flags, true, &severity, &types);
     object_name_info.sType = VK_STRUCTURE_TYPE_DEBUG_UTILS_OBJECT_NAME_INFO_EXT;
     object_name_info.pNext = NULL;
-    object_name_info.objectType = convertDebugReportObjectToCoreObject(object_type);
+    object_name_info.objectType = object_type;
     object_name_info.objectHandle = (uint64_t)(uintptr_t)src_object;
     object_name_info.pObjectName = NULL;
     std::string object_label = {};
@@ -338,7 +338,7 @@ static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags ms
     callback_data.flags = 0;
     callback_data.pMessageIdName = text_vuid;
     callback_data.messageIdNumber = 0;  // deprecated, validation layers use only the pMessageIdName
-    callback_data.pMessage = message;
+    callback_data.pMessage = NULL;
     callback_data.queueLabelCount = 0;
     callback_data.pQueueLabels = NULL;
     callback_data.cmdBufLabelCount = 0;
@@ -348,7 +348,7 @@ static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags ms
 
     std::vector<VkDebugUtilsLabelEXT> queue_labels;
     std::vector<VkDebugUtilsLabelEXT> cmd_buf_labels;
-    std::string new_debug_report_message = "";
+    std::string composite_message = "";
     std::ostringstream oss;
 
     if (0 != src_object) {
@@ -386,10 +386,15 @@ static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags ms
     } else {
         oss << "Object: VK_NULL_HANDLE (Type = " << std::to_string(object_type) << ")";
     }
-    new_debug_report_message += oss.str();
-    new_debug_report_message += " | ";
-    new_debug_report_message += message;
 
+    composite_message += oss.str();
+    composite_message += " | ";
+    composite_message += message;
+    if (text_vuid != nullptr) {
+        composite_message.insert(0, " ] ");
+        composite_message.insert(0, text_vuid);
+        composite_message.insert(0, "[ ");
+    }
     const auto callback_list = &debug_data->debug_callback_list;
 
     // We only output to default callbacks if there are no non-default callbacks
@@ -404,19 +409,15 @@ static inline bool debug_log_msg(const debug_report_data *debug_data, VkFlags ms
 
         // VK_EXT_debug_report callback (deprecated)
         if (!current_callback.IsUtils() && (current_callback.debug_report_msg_flags & msg_flags)) {
-            if (text_vuid != nullptr) {
-                // If a text vuid is supplied for the old debug report extension, prepend it to the message string
-                new_debug_report_message.insert(0, " ] ");
-                new_debug_report_message.insert(0, text_vuid);
-                new_debug_report_message.insert(0, " [ ");
-            }
-            if (current_callback.debug_report_callback_function_ptr(msg_flags, object_type, src_object, location, 0, layer_prefix,
-                                                                    new_debug_report_message.c_str(), current_callback.pUserData)) {
+            if (current_callback.debug_report_callback_function_ptr(msg_flags, convertCoreObjectToDebugReportObject(object_type),
+                                                                    src_object, location, 0, layer_prefix,
+                                                                    composite_message.c_str(), current_callback.pUserData)) {
                 bail = true;
             }
             // VK_EXT_debug_utils callback
         } else if (current_callback.IsUtils() && (current_callback.debug_utils_msg_flags & severity) &&
                    (current_callback.debug_utils_msg_type & types)) {
+            callback_data.pMessage = composite_message.c_str();
             if (current_callback.debug_utils_callback_function_ptr(static_cast<VkDebugUtilsMessageSeverityFlagBitsEXT>(severity),
                                                                    types, &callback_data, current_callback.pUserData)) {
                 bail = true;
@@ -445,6 +446,25 @@ static inline void DebugAnnotFlagsToReportFlags(VkDebugUtilsMessageSeverityFlagB
     }
 }
 
+static inline LogMessageTypeFlags DebugAnnotFlagsToMsgTypeFlags(VkDebugUtilsMessageSeverityFlagBitsEXT da_severity,
+                                                                VkDebugUtilsMessageTypeFlagsEXT da_type) {
+    LogMessageTypeFlags msg_type_flags = 0;
+    if ((da_severity & VK_DEBUG_UTILS_MESSAGE_SEVERITY_ERROR_BIT_EXT) != 0) {
+        msg_type_flags |= kErrorBit;
+    } else if ((da_severity & VK_DEBUG_UTILS_MESSAGE_SEVERITY_WARNING_BIT_EXT) != 0) {
+        if ((da_type & VK_DEBUG_UTILS_MESSAGE_TYPE_PERFORMANCE_BIT_EXT) != 0) {
+            msg_type_flags |= kPerformanceWarningBit;
+        } else {
+            msg_type_flags |= kWarningBit;
+        }
+    } else if ((da_severity & VK_DEBUG_UTILS_MESSAGE_SEVERITY_INFO_BIT_EXT) != 0) {
+        msg_type_flags |= kInformationBit;
+    } else if ((da_severity & VK_DEBUG_UTILS_MESSAGE_SEVERITY_VERBOSE_BIT_EXT) != 0) {
+        msg_type_flags |= kDebugBit;
+    }
+    return msg_type_flags;
+}
+
 static inline void layer_debug_utils_destroy_instance(debug_report_data *debug_data) {
     if (debug_data) {
         std::unique_lock<std::mutex> lock(debug_data->debug_output_mutex);
@@ -589,7 +609,7 @@ static inline int vasprintf(char **strp, char const *fmt, va_list ap) {
 #endif
 
 // This must be called with the debug_output_mutex already held
-static inline bool LogMsgLocked(const debug_report_data *debug_data, VkFlags msg_flags, VkDebugReportObjectTypeEXT object_type,
+static inline bool LogMsgLocked(const debug_report_data *debug_data, VkFlags msg_flags, VkObjectType object_type,
                                 uint64_t src_object, const std::string &vuid_text, char *err_msg) {
     std::string str_plus_spec_text(err_msg ? err_msg : "Allocation failure");
 
@@ -606,56 +626,18 @@ static inline bool LogMsgLocked(const debug_report_data *debug_data, VkFlags msg
             }
         }
 
-        if (nullptr == spec_text) {
-            // If this happens, you've hit a VUID string that isn't defined in the spec's json file
-            // Try running 'vk_validation_stats -c' to look for invalid VUID strings in the repo code
-            assert(0);
-        } else {
+        if (nullptr != spec_text) {
             str_plus_spec_text += " The Vulkan spec states: ";
             str_plus_spec_text += spec_text;
         }
     }
 
-    // Append layer prefix with VUID string, pass in recovered legacy numerical VUID
-
     bool result = debug_log_msg(debug_data, msg_flags, object_type, src_object, 0, "Validation", str_plus_spec_text.c_str(),
                                 vuid_text.c_str());
-
     free(err_msg);
     return result;
 }
 
-// Output log message via DEBUG_REPORT. Takes format and variable arg list so that output string is only computed if a message
-// needs to be logged
-#ifndef WIN32
-static inline bool log_msg(const debug_report_data *debug_data, VkFlags msg_flags, VkDebugReportObjectTypeEXT object_type,
-                           uint64_t src_object, const std::string &vuid_text, const char *format, ...)
-    __attribute__((format(printf, 6, 7)));
-#endif
-static inline bool log_msg(const debug_report_data *debug_data, VkFlags msg_flags, VkDebugReportObjectTypeEXT object_type,
-                           uint64_t src_object, const std::string &vuid_text, const char *format, ...) {
-    if (!debug_data) return false;
-    std::unique_lock<std::mutex> lock(debug_data->debug_output_mutex);
-    VkFlags local_severity = 0;
-    VkFlags local_type = 0;
-    DebugReportFlagsToAnnotFlags(msg_flags, true, &local_severity, &local_type);
-    if (!debug_data || !(debug_data->active_severities & local_severity) || !(debug_data->active_types & local_type)) {
-        // Message is not wanted
-        return false;
-    }
-
-    va_list argptr;
-    va_start(argptr, format);
-    char *str;
-    if (-1 == vasprintf(&str, format, argptr)) {
-        // On failure, glibc vasprintf leaves str undefined
-        str = nullptr;
-    }
-    va_end(argptr);
-
-    return LogMsgLocked(debug_data, msg_flags, object_type, src_object, vuid_text, str);
-}
-
 static inline VKAPI_ATTR VkBool32 VKAPI_CALL report_log_callback(VkFlags msg_flags, VkDebugReportObjectTypeEXT obj_type,
                                                                  uint64_t src_object, size_t location, int32_t msg_code,
                                                                  const char *layer_prefix, const char *message, void *user_data) {
